@@ -1,3 +1,6 @@
+// SPDX-License-Identifier: Apache-2.0
+// Copyright Authors of K9s
+
 package config
 
 import (
@@ -15,19 +18,23 @@ type K9s struct {
 	RefreshRate         int                 `yaml:"refreshRate"`
 	MaxConnRetry        int                 `yaml:"maxConnRetry"`
 	EnableMouse         bool                `yaml:"enableMouse"`
+	EnableImageScan     bool                `yaml:"enableImageScan"`
 	Headless            bool                `yaml:"headless"`
 	Logoless            bool                `yaml:"logoless"`
 	Crumbsless          bool                `yaml:"crumbsless"`
 	ReadOnly            bool                `yaml:"readOnly"`
 	NoExitOnCtrlC       bool                `yaml:"noExitOnCtrlC"`
 	NoIcons             bool                `yaml:"noIcons"`
+	ShellPod            *ShellPod           `yaml:"shellPod"`
 	SkipLatestRevCheck  bool                `yaml:"skipLatestRevCheck"`
 	Logger              *Logger             `yaml:"logger"`
 	CurrentContext      string              `yaml:"currentContext"`
 	CurrentCluster      string              `yaml:"currentCluster"`
+	KeepMissingClusters bool                `yaml:"keepMissingClusters"`
 	Clusters            map[string]*Cluster `yaml:"clusters,omitempty"`
 	Thresholds          Threshold           `yaml:"thresholds"`
 	ScreenDumpDir       string              `yaml:"screenDumpDir"`
+	DisablePodCounting  bool                `yaml:"disablePodCounting"`
 	manualRefreshRate   int
 	manualHeadless      *bool
 	manualLogoless      *bool
@@ -46,6 +53,7 @@ func NewK9s() *K9s {
 		Clusters:      make(map[string]*Cluster),
 		Thresholds:    NewThreshold(),
 		ScreenDumpDir: K9sDefaultScreenDumpDir,
+		ShellPod:      NewShellPod(),
 	}
 }
 
@@ -206,9 +214,17 @@ func (k *K9s) validateClusters(c client.Connection, ks KubeSettings) {
 	}
 	for key, cluster := range k.Clusters {
 		cluster.Validate(c, ks)
+		// if the cluster is defined in the $KUBECONFIG file, keep it in the k9s config file
 		if _, ok := cc[key]; ok {
 			continue
 		}
+
+		// if we asked to keep the clusters in the config file
+		if k.KeepMissingClusters {
+			continue
+		}
+
+		// else remove it from the k9s config file
 		if k.CurrentCluster == key {
 			k.CurrentCluster = ""
 		}
@@ -224,6 +240,11 @@ func (k *K9s) Validate(c client.Connection, ks KubeSettings) {
 	}
 	k.validateClusters(c, ks)
 
+	if k.ShellPod == nil {
+		k.ShellPod = NewShellPod()
+	}
+	k.ShellPod.Validate(c, ks)
+
 	if k.Logger == nil {
 		k.Logger = NewLogger()
 	} else {
