@@ -1,3 +1,6 @@
+// SPDX-License-Identifier: Apache-2.0
+// Copyright Authors of K9s
+
 package dao
 
 import (
@@ -7,6 +10,7 @@ import (
 
 	"github.com/derailed/k9s/internal"
 	"github.com/derailed/k9s/internal/client"
+	"github.com/derailed/k9s/internal/render"
 	"github.com/rs/zerolog/log"
 	batchv1 "k8s.io/api/batch/v1"
 	"k8s.io/apimachinery/pkg/apis/meta/v1/unstructured"
@@ -15,9 +19,10 @@ import (
 )
 
 var (
-	_ Accessor = (*Job)(nil)
-	_ Nuker    = (*Job)(nil)
-	_ Loggable = (*Job)(nil)
+	_ Accessor    = (*Job)(nil)
+	_ Nuker       = (*Job)(nil)
+	_ Loggable    = (*Job)(nil)
+	_ ImageLister = (*Deployment)(nil)
 )
 
 // Job represents a K8s job resource.
@@ -25,6 +30,16 @@ type Job struct {
 	Resource
 }
 
+// ListImages lists container images.
+func (j *Job) ListImages(ctx context.Context, fqn string) ([]string, error) {
+	job, err := j.GetInstance(fqn)
+	if err != nil {
+		return nil, err
+	}
+
+	return render.ExtractImages(&job.Spec.Template.Spec), nil
+}
+
 // List returns a collection of resources.
 func (j *Job) List(ctx context.Context, ns string) ([]runtime.Object, error) {
 	oo, err := j.Resource.List(ctx, ns)
@@ -76,6 +91,21 @@ func (j *Job) TailLogs(ctx context.Context, opts *LogOptions) ([]LogChan, error)
 	return podLogs(ctx, job.Spec.Selector.MatchLabels, opts)
 }
 
+func (j *Job) GetInstance(fqn string) (*batchv1.Job, error) {
+	o, err := j.GetFactory().Get(j.gvr.String(), fqn, true, labels.Everything())
+	if err != nil {
+		return nil, err
+	}
+
+	var job batchv1.Job
+	err = runtime.DefaultUnstructuredConverter.FromUnstructured(o.(*unstructured.Unstructured).Object, &job)
+	if err != nil {
+		return nil, errors.New("expecting a job resource")
+	}
+
+	return &job, nil
+}
+
 // ScanSA scans for serviceaccount refs.
 func (j *Job) ScanSA(ctx context.Context, fqn string, wait bool) (Refs, error) {
 	ns, n := client.Namespaced(fqn)
