@@ -1,3 +1,6 @@
+// SPDX-License-Identifier: Apache-2.0
+// Copyright Authors of K9s
+
 package dao
 
 import (
@@ -30,6 +33,7 @@ var (
 	_ Loggable        = (*Pod)(nil)
 	_ Controller      = (*Pod)(nil)
 	_ ContainsPodSpec = (*Pod)(nil)
+	_ ImageLister     = (*Pod)(nil)
 )
 
 const (
@@ -73,6 +77,16 @@ func (p *Pod) Get(ctx context.Context, path string) (runtime.Object, error) {
 	return &render.PodWithMetrics{Raw: u, MX: pmx}, nil
 }
 
+// ListImages lists container images.
+func (p *Pod) ListImages(ctx context.Context, path string) ([]string, error) {
+	pod, err := p.GetInstance(path)
+	if err != nil {
+		return nil, err
+	}
+
+	return render.ExtractImages(&pod.Spec), nil
+}
+
 // List returns a collection of nodes.
 func (p *Pod) List(ctx context.Context, ns string) ([]runtime.Object, error) {
 	oo, err := p.Resource.List(ctx, ns)
@@ -520,12 +534,19 @@ func (p *Pod) Sanitize(ctx context.Context, ns string) (int, error) {
 		}
 		log.Debug().Msgf("Pod status: %q", render.PodStatus(&pod))
 		switch render.PodStatus(&pod) {
-		case render.PhaseCompleted, render.PhaseCrashLoop, render.PhaseError, render.PhaseImagePullBackOff, render.PhaseOOMKilled:
+		case render.PhaseCompleted:
+			fallthrough
+		case render.PhaseCrashLoop:
+			fallthrough
+		case render.PhaseError:
+			fallthrough
+		case render.PhaseImagePullBackOff:
+			fallthrough
+		case render.PhaseOOMKilled:
 			log.Debug().Msgf("Sanitizing %s:%s", pod.Namespace, pod.Name)
 			fqn := client.FQN(pod.Namespace, pod.Name)
 			if err := p.Resource.Delete(ctx, fqn, nil, NowGrace); err != nil {
-				log.Warn().Err(err).Msgf("Pod %s deletion failed", fqn)
-				continue
+				return count, err
 			}
 			count++
 		}
