@@ -1,3 +1,6 @@
+// SPDX-License-Identifier: Apache-2.0
+// Copyright Authors of K9s
+
 package dao
 
 import (
@@ -7,6 +10,7 @@ import (
 	"strings"
 
 	"github.com/derailed/k9s/internal/client"
+	"github.com/derailed/k9s/internal/render"
 	"github.com/rs/zerolog/log"
 	appsv1 "k8s.io/api/apps/v1"
 	v1 "k8s.io/api/core/v1"
@@ -28,6 +32,7 @@ var (
 	_ Scalable        = (*StatefulSet)(nil)
 	_ Controller      = (*StatefulSet)(nil)
 	_ ContainsPodSpec = (*StatefulSet)(nil)
+	_ ImageLister     = (*StatefulSet)(nil)
 )
 
 // StatefulSet represents a K8s sts.
@@ -35,6 +40,16 @@ type StatefulSet struct {
 	Resource
 }
 
+// ListImages lists container images.
+func (s *StatefulSet) ListImages(ctx context.Context, fqn string) ([]string, error) {
+	sts, err := s.GetInstance(s.Factory, fqn)
+	if err != nil {
+		return nil, err
+	}
+
+	return render.ExtractImages(&sts.Spec.Template.Spec), nil
+}
+
 // IsHappy check for happy sts.
 func (s *StatefulSet) IsHappy(sts appsv1.StatefulSet) bool {
 	return sts.Status.Replicas == sts.Status.ReadyReplicas
