@@ -1,3 +1,6 @@
+// SPDX-License-Identifier: Apache-2.0
+// Copyright Authors of K9s
+
 package render
 
 import (
@@ -6,6 +9,7 @@ import (
 	"strings"
 
 	"github.com/derailed/k9s/internal/client"
+	"github.com/derailed/k9s/internal/vul"
 	batchv1 "k8s.io/api/batch/v1"
 	v1 "k8s.io/api/core/v1"
 	"k8s.io/apimachinery/pkg/apis/meta/v1/unstructured"
@@ -19,9 +23,10 @@ type CronJob struct {
 
 // Header returns a header row.
 func (CronJob) Header(ns string) Header {
-	return Header{
+	h := Header{
 		HeaderColumn{Name: "NAMESPACE"},
 		HeaderColumn{Name: "NAME"},
+		HeaderColumn{Name: "VS"},
 		HeaderColumn{Name: "SCHEDULE"},
 		HeaderColumn{Name: "SUSPEND"},
 		HeaderColumn{Name: "ACTIVE"},
@@ -33,13 +38,19 @@ func (CronJob) Header(ns string) Header {
 		HeaderColumn{Name: "VALID", Wide: true},
 		HeaderColumn{Name: "AGE", Time: true},
 	}
+	if vul.ImgScanner == nil {
+		h = append(h[:vulIdx], h[vulIdx+1:]...)
+	}
+
+	return h
+
 }
 
 // Render renders a K8s resource to screen.
 func (c CronJob) Render(o interface{}, ns string, r *Row) error {
 	raw, ok := o.(*unstructured.Unstructured)
 	if !ok {
-		return fmt.Errorf("Expected CronJob, but got %T", o)
+		return fmt.Errorf("expected CronJob, but got %T", o)
 	}
 	var cj batchv1.CronJob
 	err := runtime.DefaultUnstructuredConverter.FromUnstructured(raw.Object, &cj)
@@ -49,13 +60,14 @@ func (c CronJob) Render(o interface{}, ns string, r *Row) error {
 
 	lastScheduled := "<none>"
 	if cj.Status.LastScheduleTime != nil {
-		lastScheduled = toAge(*cj.Status.LastScheduleTime)
+		lastScheduled = ToAge(*cj.Status.LastScheduleTime)
 	}
 
 	r.ID = client.MetaFQN(cj.ObjectMeta)
 	r.Fields = Fields{
 		cj.Namespace,
 		cj.Name,
+		computeVulScore(&cj.Spec.JobTemplate.Spec.Template.Spec),
 		cj.Spec.Schedule,
 		boolPtrToStr(cj.Spec.Suspend),
 		strconv.Itoa(len(cj.Status.Active)),
@@ -65,7 +77,10 @@ func (c CronJob) Render(o interface{}, ns string, r *Row) error {
 		podImageNames(cj.Spec.JobTemplate.Spec.Template.Spec, true),
 		mapToStr(cj.Labels),
 		"",
-		toAge(cj.GetCreationTimestamp()),
+		ToAge(cj.GetCreationTimestamp()),
+	}
+	if vul.ImgScanner == nil {
+		r.Fields = append(r.Fields[:vulIdx], r.Fields[vulIdx+1:]...)
 	}
 
 	return nil
