@@ -1,3 +1,6 @@
+// SPDX-License-Identifier: Apache-2.0
+// Copyright Authors of K9s
+
 package render
 
 import (
@@ -32,6 +35,7 @@ func (Node) Header(_ string) Header {
 		HeaderColumn{Name: "NAME"},
 		HeaderColumn{Name: "STATUS"},
 		HeaderColumn{Name: "ROLE"},
+		HeaderColumn{Name: "TAINTS"},
 		HeaderColumn{Name: "VERSION"},
 		HeaderColumn{Name: "KERNEL", Wide: true},
 		HeaderColumn{Name: "INTERNAL-IP", Wide: true},
@@ -53,11 +57,11 @@ func (Node) Header(_ string) Header {
 func (n Node) Render(o interface{}, ns string, r *Row) error {
 	oo, ok := o.(*NodeWithMetrics)
 	if !ok {
-		return fmt.Errorf("Expected *NodeAndMetrics, but got %T", o)
+		return fmt.Errorf("expected *NodeAndMetrics, but got %T", o)
 	}
 	meta, ok := oo.Raw.Object["metadata"].(map[string]interface{})
 	if !ok {
-		return fmt.Errorf("Unable to extract meta")
+		return fmt.Errorf("unable to extract meta")
 	}
 	na := extractMetaField(meta, "name")
 	var no v1.Node
@@ -77,16 +81,21 @@ func (n Node) Render(o interface{}, ns string, r *Row) error {
 	nodeRoles(&no, roles)
 	sort.Sort(roles)
 
+	podCount := strconv.Itoa(oo.PodCount)
+	if pc := oo.PodCount; pc == -1 {
+		podCount = NAValue
+	}
 	r.ID = client.FQN("", na)
 	r.Fields = Fields{
 		no.Name,
 		join(statuses, ","),
 		join(roles, ","),
+		strconv.Itoa(len(no.Spec.Taints)),
 		no.Status.NodeInfo.KubeletVersion,
 		no.Status.NodeInfo.KernelVersion,
 		iIP,
 		eIP,
-		strconv.Itoa(oo.PodCount),
+		podCount,
 		toMc(c.cpu),
 		toMi(c.mem),
 		client.ToPercentageStr(c.cpu, a.cpu),
@@ -94,8 +103,8 @@ func (n Node) Render(o interface{}, ns string, r *Row) error {
 		toMc(a.cpu),
 		toMi(a.mem),
 		mapToStr(no.Labels),
-		asStatus(n.diagnose(statuses)),
-		toAge(no.GetCreationTimestamp()),
+		AsStatus(n.diagnose(statuses)),
+		ToAge(no.GetCreationTimestamp()),
 	}
 
 	return nil
